@@ -3,21 +3,23 @@ import logging
 import os
 import subprocess
 import sys
-import uuid
 import traceback
-
+import uuid
 from datetime import datetime
 from shutil import which
 from subprocess import PIPE, Popen
 
 import nbformat
 import yaml
+from allauth.account.admin import EmailAddress
 from celery import shared_task
 from croniter import croniter
 from django.conf import settings
+from django.contrib.auth.models import User
 from django.template.defaultfilters import slugify
 from django.utils.timezone import make_aware
 
+from apps.accounts.models import Site
 from apps.nb.exporter import Exporter
 from apps.notebooks.models import Notebook
 from apps.notebooks.slides_themes import SlidesThemes
@@ -213,6 +215,29 @@ def task_init_notebook(
         parse_errors = validate_notify(notebook_notify)
 
         if notebook_id is None:
+            site, user = None, None
+
+            if not User.objects.filter(username="developer"):
+                user = User.objects.create_user(
+                    username="developer",
+                    email="developer@example.com",
+                    password="developer",
+                )
+                EmailAddress.objects.create(
+                    user=user, email=user.email, verified=True, primary=True
+                )
+            else:
+                user = User.objects.get(username="developer")
+            if not Site.objects.filter(slug="single-site"):
+                site = Site.objects.create(
+                    title="Mercury",
+                    slug="single-site",
+                    share=Site.PUBLIC,
+                    created_by=user,
+                )
+            else:
+                site = Site.objects.get(slug="single-site")
+
             notebook = Notebook(
                 title=notebook_title,
                 slug=notebook_slug,
@@ -231,6 +256,8 @@ def task_init_notebook(
                 schedule=notebook_schedule,
                 notify=json.dumps(notebook_notify),
                 errors=parse_errors,
+                created_by=user,
+                hosted_on=site,
             )
         else:
             notebook = Notebook.objects.get(pk=notebook_id)
