@@ -1,18 +1,11 @@
 from django.conf.urls import include, url
 from rest_framework.routers import DefaultRouter
 
-from apps.tasks.views import (
-    ClearTasksView,
-    CreateRestAPITask,
-    ExecutionHistoryView,
-    ExportPDF,
-    GetLastTaskView,
-    GetPDFAddress,
-    GetRestAPITask,
-    ListOutputFilesView,
-    ListWorkerOutputFilesView,
-    TaskCreateView,
-)
+from apps.tasks.views import (ClearTasksView, CreateRestAPITask,
+                              ExecutionHistoryView, ExportPDF, GetLastTaskView,
+                              GetPDFAddress, GetRestAPITask,
+                              ListOutputFilesView, ListWorkerOutputFilesView,
+                              TaskCreateView)
 
 tasks_urlpatterns = [
     url("api/v1/execute/(?P<notebook_id>.+)", TaskCreateView.as_view()),
