@@ -7,7 +7,7 @@ from django.urls import path, re_path
 
 from apps.notebooks.urls import notebooks_urlpatterns
 from apps.tasks.urls import tasks_urlpatterns
-from server.settings import is_pro
+from apps.accounts.urls import accounts_urlpatterns
 from server.views import VersionInfo, WelcomeMessage
 
 urlpatterns = []
@@ -34,7 +34,7 @@ urlpatterns += [
         VersionInfo.as_view(),
     ),
     url(
-        "api/v1/welcome",
+        "api/v1/(?P<site_id>.+)/welcome",
         WelcomeMessage.as_view(),
     ),
     re_path(r"^api/v1/fp/", include("django_drf_filepond.urls")),
@@ -42,11 +42,7 @@ urlpatterns += [
 
 urlpatterns += tasks_urlpatterns
 urlpatterns += notebooks_urlpatterns
-
-if is_pro:
-    from pro.accounts.urls import auth_urlpatterns
-
-    urlpatterns += auth_urlpatterns
+urlpatterns += accounts_urlpatterns
 
 
 admin.site.site_header = "Mercury Admin Panel"
